@@ -458,11 +458,12 @@ class GNet(GBase):
     def stream_filetype_url(url):
         headers = GNet.user_agent
         req = urllib.request.Request(url, headers=headers)
-        with urllib.request.urlopen(req) as response:
-            try:
+        try:
+            with urllib.request.urlopen(req) as response:
                 headers = response.getheader('Content-Type')
-            except Exception as ex:
-                print(ex)
+        except Exception as ex:
+            print(ex)
+            return False
 
         content_type = ''
         if headers == 'audio/aacp' or headers == 'application/aacp':
@@ -508,7 +509,7 @@ class GNet(GBase):
                         # write in dict for no metadata = true
                     except Exception as ex:
                         print(ex)
-                        print(' server has no metadata - try record into one file ')
+                        print(f' ---> {key}: no html title-info, no stream metadata, must be deleted; no record')
                         GNet.is_no_meta_avail_dict[key] = True
 
             return True
@@ -560,7 +561,7 @@ class GRecorder:
             #
             if not len(stream_song_name) <= 2:
                 #  GRecorder.current_song_dict[ini_key] = stream_song_name  # WRITE SONG NAME   # :DEACTIVATED:
-                stream_song_name = GRecorder.current_song_dict[ini_key]                         # :REVERSE:
+                stream_song_name = GRecorder.current_song_dict[ini_key]  # :REVERSE:
 
                 if not update_terminal == stream_song_name:
                     update_terminal = stream_song_name
@@ -568,7 +569,9 @@ class GRecorder:
                         print('\t\t title on ' + ini_key + ':\t' + update_terminal)
                         # see what happens. looks like a unit test case
                     except UnicodeEncodeError:
-                        print('\t\t title on ' + ini_key + ':\t' + 'unicode error (check "locale" settings)')
+                        print('\t\t title on ' + ini_key + ':\t' + 'unicode error (check "$ localectl status")')
+                        print('\t\t title on ' + ini_key + ':\t' + 'consider to add additional language support.')
+
                     except Exception as ex:
                         print('\t\t title on ' + ini_key + ':\t' + 'unknown error (print to your terminal)')
                         print(ex)
@@ -784,6 +787,8 @@ class GRecorder:
         old_time = time()
         must_run = False
         brake_loop = False
+        rand_short = random.randrange(4, 13, 3)
+        rand_long = random.randrange(61, 90, 1)
 
         ghetto_recorder = path_to_save + '//__ghetto_recorder.mp3'
         ghetto_copy = GRecorder.path_to_song_dict[key]  # generates exception, if no dict val
@@ -799,13 +804,16 @@ class GRecorder:
                         print(f'----> start record: {key}')
                     break
 
-            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10)
+            request = GNet.http_pool.request('GET', url,
+                                             headers={'Connection': 'keep-alive'},
+                                             timeout=3000,
+                                             preload_content=False)
             while not GBase.exit_app:
                 with open(ghetto_recorder, 'wb') as record_file:
                     if brake_loop:  # start_stop_recording stop, can change again to start at run.
                         break
-                    rand = random.randrange(4, 12, 2)  # sleep random
-                    for chunk in request.stream(stream_request_size):  # create file
+
+                    for chunk in request.stream(stream_request_size):  # chunks to file
 
                         if GIni.start_stop_recording[key] == 'stop':
                             must_run = False
@@ -824,7 +832,21 @@ class GRecorder:
 
                         record_file.write(chunk)  # start writing ...
 
+                        if time() - old_time > rand_short:
+                            old_time = time()
+                            rh = request.headers
+                            rand_short = random.randrange(4, 12, 2)
+
+                        if time() - old_time > rand_long:
+                            old_time = time()
+                            request = GNet.http_pool.request('GET', url,
+                                                             headers={'Connection': 'keep-alive'},
+                                                             timeout=3000,
+                                                             preload_content=False)
+                            rand_long = random.randrange(61, 90, 1)
+                            rand_short = random.randrange(4, 13, 3)
                         if not ghetto_copy == GRecorder.path_to_song_dict[key]:  # Compare OLD PATH
+                            ghetto_copy = GRecorder.path_to_song_dict[key]      # SET NEW PATH
                             try:
                                 if os.path.exists(ghetto_copy):
                                     os.remove(ghetto_copy)
@@ -836,12 +858,13 @@ class GRecorder:
                                 record_file.truncate()
                                 record_file.seek(0)
 
-                        ghetto_copy = GRecorder.path_to_song_dict[key]  # SET NEW PATH
-                        if time() - old_time > rand:
-                            old_time = time()
                         if not chunk:
-                            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10)
-
+                            request = GNet.http_pool.request('GET', url,
+                                                             headers={'Connection': 'keep-alive'},
+                                                             timeout=3000,
+                                                             preload_content=False)
+                            rh = request.headers
+                            break
                         if GBase.exit_app:
                             sleep(2)  # wait for last file name _incomplete_.....
                             try:
@@ -857,6 +880,8 @@ class GRecorder:
 
                                 if os.path.exists(ghetto_recorder):
                                     os.remove(ghetto_recorder)
+                            except UnicodeEncodeError:
+                                print(f' {key} copy last file to folder (marked: _incomplete_):')
                             except Exception as ex:
                                 print(ex)
                             break
@@ -880,11 +905,11 @@ class GRecorder:
 
             while not GBase.exit_app:
                 rand_short = random.randrange(4, 12, 2)
-                rand_long = random.randrange(50, 80, 1)  # sleep random
+                rand_long = random.randrange(50, 80, 1)
 
                 if time() - old_time > rand_short:
                     old_time = time()
-                    rh = response.headers   # keep conn. alive
+                    rh = response.headers  # keep conn. alive
                     # print(response.headers)
 
                 if time() - old_time > rand_long:  # new connection
@@ -917,8 +942,10 @@ class GRecorder:
                     # print(f' -> {key} + {title_info}')
                     try:
                         GRecorder.current_song_dict[key] = title_info
-                    except Exception as ex:
-                        print(ex)
+
+                    except KeyError:
+                        pass
+                    except:
                         pass
                     else:
                         for sec in range(rand_short):
@@ -992,7 +1019,7 @@ class GRecorder:
 
                         fresh_file = directory_save + '//' + clean_name + stream_suffix
                         GRecorder.path_to_song_dict[radio_short_key] = fresh_file  # new file  with PATH!!!
-                        print(f'GRecorder.current_song_dict  {GRecorder.current_song_dict[radio_short_key]}')
+                        # print(f'GRecorder.current_song_dict  {GRecorder.current_song_dict[radio_short_key]}')
                         while not GBase.exit_app:  # inner loop get the stream and write into file
 
                             stream_song_name_path_new = GRecorder.path_to_song_dict[radio_short_key]  # look what's new
@@ -1194,6 +1221,13 @@ def step2_test_stream_server(ini_keys):
             pass
             # print(f"The outcome is {fut.result()} {fut.__dict__}")
 
+    for radio in GNet.is_no_meta_avail_dict:
+        radio_failed = GNet.is_no_meta_avail_dict[radio]
+        if radio_failed:
+            del GIni.ini_keys[radio]
+            print(f' ---> {radio}: deleted from record list. Check, if server has multiple '
+                  f'streams (quality or user limits) {GIni.srv_param_dict[radio]}')
+
     record(ini_keys)
     # record(ini_keys, GIni.srv_param_dict)  # this starts record threads and loops at end for shutdown signal
 
@@ -1221,10 +1255,13 @@ def record(ini_keys):
     signal.signal(signal.SIGINT, signal_handler)
 
     for ini_key in ini_keys:
-        # try:
-        stream_suffix = GIni.srv_param_dict[ini_key + '_file']  # quick fix
-        # except KeyError:
-        # stream_suffix = '.mp3'
+        stream_suffix = '.mp3'  # fix for 50%, lol
+        try:
+            stream_suffix = GIni.srv_param_dict[ini_key + '_file']  # sometimes malformed content-type written?
+        except KeyError:
+            stream_suffix = '.mp3'
+        except Exception as ex:
+            pass
 
         GRecorder.current_song_dict[ini_key] = '_no-name-record_no_split_'  # init the dict for this thread
         GIni.start_stop_recording[ini_key] = 'start'
@@ -1260,13 +1297,16 @@ def test_stream_server(key):
     # each server type property has a dict, { radio name : False/True}, with a small db it would be much cleaner
     # GNet.is_shout_ice_unknown_server(server_port, full_url, key)
     if GNet.is_shout_ice_unknown_server(GIni.srv_param_dict[ini_keys[key]], GIni.srv_param_dict[key], key):
+        # if this server is halfway a radio server
 
         # str_in is input, modify to get more dictionary keys; file type, is shout is ice ...
         ret = GNet.stream_filetype_url(GIni.srv_param_dict[key])
-
-        GIni.srv_param_dict[key + '_file'] = ret
-        if ret is None or ret == '' or ret == ' ':
-            GIni.srv_param_dict[key + '_file'] = '.mp3'
+        if not ret:
+            GIni.srv_param_dict[key + '_is_no_meta_data_avail'] = 'True'
+        else:
+            GIni.srv_param_dict[key + '_file'] = ret
+            if ret is None or ret == '' or ret == ' ':
+                GIni.srv_param_dict[key + '_file'] = '.mp3'
 
         if GNet.is_shout_dict[key]:
             GIni.srv_param_dict[key + '_is_shoutcast_server'] = 'True'
