@@ -508,7 +508,7 @@ class GNet(GBase):
                         # write in dict for no metadata = true
                     except Exception as ex:
                         print(ex)
-                        print(' server has no metadata - try record into one file ')
+                        print(f' {key}: no html title-info, no stream metadata, must be deleted; no record')
                         GNet.is_no_meta_avail_dict[key] = True
 
             return True
@@ -560,7 +560,7 @@ class GRecorder:
             #
             if not len(stream_song_name) <= 2:
                 #  GRecorder.current_song_dict[ini_key] = stream_song_name  # WRITE SONG NAME   # :DEACTIVATED:
-                stream_song_name = GRecorder.current_song_dict[ini_key]                         # :REVERSE:
+                stream_song_name = GRecorder.current_song_dict[ini_key]  # :REVERSE:
 
                 if not update_terminal == stream_song_name:
                     update_terminal = stream_song_name
@@ -786,6 +786,8 @@ class GRecorder:
         old_time = time()
         must_run = False
         brake_loop = False
+        rand_short = random.randrange(4, 13, 3)
+        rand_long = random.randrange(61, 90, 1)
 
         ghetto_recorder = path_to_save + '//__ghetto_recorder.mp3'
         ghetto_copy = GRecorder.path_to_song_dict[key]  # generates exception, if no dict val
@@ -801,13 +803,16 @@ class GRecorder:
                         print(f'----> start record: {key}')
                     break
 
-            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10)
+            request = GNet.http_pool.request('GET', url,
+                                             headers={'Connection': 'keep-alive'},
+                                             timeout=3000,
+                                             preload_content=False)
             while not GBase.exit_app:
                 with open(ghetto_recorder, 'wb') as record_file:
                     if brake_loop:  # start_stop_recording stop, can change again to start at run.
                         break
-                    rand = random.randrange(4, 12, 2)  # sleep random
-                    for chunk in request.stream(stream_request_size):  # create file
+
+                    for chunk in request.stream(stream_request_size):  # chunks to file
 
                         if GIni.start_stop_recording[key] == 'stop':
                             must_run = False
@@ -826,7 +831,21 @@ class GRecorder:
 
                         record_file.write(chunk)  # start writing ...
 
+                        if time() - old_time > rand_short:
+                            old_time = time()
+                            rh = request.headers
+                            rand_short = random.randrange(4, 12, 2)
+
+                        if time() - old_time > rand_long:
+                            old_time = time()
+                            request = GNet.http_pool.request('GET', url,
+                                                             headers={'Connection': 'keep-alive'},
+                                                             timeout=3000,
+                                                             preload_content=False)
+                            rand_long = random.randrange(61, 90, 1)
+                            rand_short = random.randrange(4, 13, 3)
                         if not ghetto_copy == GRecorder.path_to_song_dict[key]:  # Compare OLD PATH
+                            ghetto_copy = GRecorder.path_to_song_dict[key]      # SET NEW PATH
                             try:
                                 if os.path.exists(ghetto_copy):
                                     os.remove(ghetto_copy)
@@ -838,12 +857,13 @@ class GRecorder:
                                 record_file.truncate()
                                 record_file.seek(0)
 
-                        ghetto_copy = GRecorder.path_to_song_dict[key]  # SET NEW PATH
-                        if time() - old_time > rand:
-                            old_time = time()
                         if not chunk:
-                            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10)
-
+                            request = GNet.http_pool.request('GET', url,
+                                                             headers={'Connection': 'keep-alive'},
+                                                             timeout=3000,
+                                                             preload_content=False)
+                            rh = request.headers
+                            break
                         if GBase.exit_app:
                             sleep(2)  # wait for last file name _incomplete_.....
                             try:
@@ -884,11 +904,11 @@ class GRecorder:
 
             while not GBase.exit_app:
                 rand_short = random.randrange(4, 12, 2)
-                rand_long = random.randrange(50, 80, 1)  # sleep random
+                rand_long = random.randrange(50, 80, 1)
 
                 if time() - old_time > rand_short:
                     old_time = time()
-                    rh = response.headers   # keep conn. alive
+                    rh = response.headers  # keep conn. alive
                     # print(response.headers)
 
                 if time() - old_time > rand_long:  # new connection
@@ -921,8 +941,10 @@ class GRecorder:
                     # print(f' -> {key} + {title_info}')
                     try:
                         GRecorder.current_song_dict[key] = title_info
-                    except Exception as ex:
-                        print(ex)
+
+                    except KeyError:
+                        pass
+                    except:
                         pass
                     else:
                         for sec in range(rand_short):
@@ -1198,6 +1220,13 @@ def step2_test_stream_server(ini_keys):
             pass
             # print(f"The outcome is {fut.result()} {fut.__dict__}")
 
+    for radio in GNet.is_no_meta_avail_dict:
+        radio_failed = GNet.is_no_meta_avail_dict[radio]
+        if radio_failed:
+            del GIni.ini_keys[radio]
+            print(f' ---> {radio}: deleted from record list. Check, if server has multiple '
+                  f'streams (quality or user limits) {GIni.srv_param_dict[radio]}')
+
     record(ini_keys)
     # record(ini_keys, GIni.srv_param_dict)  # this starts record threads and loops at end for shutdown signal
 
@@ -1225,7 +1254,7 @@ def record(ini_keys):
     signal.signal(signal.SIGINT, signal_handler)
 
     for ini_key in ini_keys:
-        stream_suffix = '.mp3'                                      # fix for 50%, lol
+        stream_suffix = '.mp3'  # fix for 50%, lol
         try:
             stream_suffix = GIni.srv_param_dict[ini_key + '_file']  # sometimes malformed content-type written?
         except KeyError:
