@@ -339,7 +339,12 @@ class UIWindow(tk.Tk):
         for key in term.GIni.ini_keys:
             term.test_stream_server(key)
         # term.step2_test_stream_server(term.GIni.ini_keys) not yet
-
+        for radio in term.GNet.is_no_meta_avail_dict:
+            radio_failed = term.GNet.is_no_meta_avail_dict[radio]
+            if radio_failed:
+                del term.GIni.ini_keys[radio]
+                print(f' ---> {radio}: deleted from record list. Check, if server has multiple '
+                      f'streams (quality or user limits) {term.GIni.srv_param_dict[radio]}')
         for key in term.GIni.ini_keys:
             # term.GBase.pool.submit(term.record, key)
             term.GBase.pool.submit(self.start_records, key)
